==> Repetier-Server-Frontend-0.86.2.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/import.component.ts <==
/* (C) 2016 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */


import {Component} from '@angular/core';
import {
    ServerFolderState, RSBrowseFolder, GroupState, PrintersState,
    ServerState, PrinterState, PrinterAction, INITIAL_SERVER_FOLDER_STATE,
    ConnectionHandler
} from "@repetier/binding";
import {RSSelect} from "@repetier/front-ui";
import {select} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ISubscription} from "rxjs/Subscription";

@Component({
    selector: 'rs-import-component',
    template: `
<rs-page>
<side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</side>
<side>
    <rs-sideicon *ngIf="page==1" title="<?php _('Refresh') ?>" icon="fa fa-refresh" (rsclick)="refresh()"></rs-sideicon>
</side>
<side>
    <rs-sideicon *ngIf="server.serverFolders.length > 1 && page==1" title="<?php _('Back') ?>" icon="fa fa-reply" (rsclick)="page=0"></rs-sideicon>
</side>
<main>
<div *ngIf="page==0 && active">
    <h1><?php _('Import') ?></h1>
    <div class="content-h1 margin-leftright" rs-drag>
        <div *ngFor="let f of server.serverFolders" class="margin-bottom">
            <rs-button (hit)="selectFolder(f)" class="secondary full">{{f.name}}</rs-button>
        </div>
    </div>
</div>
<div  *ngIf="page==1">
    <h1><?php _('Import')?>: {{bFolder.activeFolderPath}}</h1>
    <div class="content-h1 margin-leftright" rs-drag>
        <div class="entry-list">
            <div class="entry left buttons" [class.single2]="p.isDir" *ngFor="let p of bFolder?.filesInPath">
                <rs-button class="primary left" (hit)="bFolder.toggleSelectFile(p)"><i class="fa" [class.fa-download]="!p.isDir" [class.fa-arrow-circle-right]="p.isDir"></i></rs-button>
                <h3><i [class]="p.icon"></i> {{p.name}}</h3>
                <p *ngIf="!p.isDir">{{p.size | byte}}</p>
            </div>
        </div>
    </div>
</div>
<div *ngIf="page==2">
    <h1><?php _('Importing ...')?></h1>
    <div class="content-h1 margin-leftright" rs-drag>
    <p>{{transImport()}}</p>
        <rs-button class="secondary margin-leftright margin-bottom" style="display:block" (hit)="selectGroup()">{{group?.name}}</rs-button>
        <rs-button class="secondary margin-leftright margin-bottom" style="display:block" (hit)="importModel()">{{transImportTo(group?.name)}}</rs-button><br>
        <rs-button *ngIf="active.queue.length==0" class="secondary margin-leftright margin-bottom" style="display:block" (hit)="importJob()"><?php _('Print File') ?></rs-button>
        <rs-button *ngIf="active.queue.length!=0" class="secondary margin-leftright margin-bottom" style="display:block" (hit)="importJob()"><?php _('Add to Print Queue') ?></rs-button>
    </div>
</div>
</main>
</rs-page>
    `
})
export class ImportComponent {
    page: number = 0; // 0 = folder select, 1 = file select
    group: GroupState;
    folder: ServerFolderState = Object.assign({}, INITIAL_SERVER_FOLDER_STATE);
    bFolder: RSBrowseFolder;
    importMsg: string;
    printers: PrintersState;
    active: PrinterState;
    server: ServerState;

    @select('printers') printers$: Observable<PrintersState>;
    @select('server') server$: Observable<ServerState>;

    private printersSubscription: ISubscription;
    private serverSubscription: ISubscription;

    constructor(private connectionHandler: ConnectionHandler,
                public select: RSSelect, private printerAction: PrinterAction) {
        this.printersSubscription = this.printers$.subscribe(p => {
            this.printers = p;
            if (p.active) {
                this.active = this.printers.printers[p.active];
                this.group = this.active.groups[this.active.activeGroupId];
            }
        });
        this.serverSubscription = this.server$.subscribe((s: ServerState) => {
            this.server = s;
            if (this.server.serverFolders.length == 1 && this.page == 0) {
                this.selectFolder(this.server.serverFolders[0]);
            }
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
        this.serverSubscription.unsubscribe();
    }

    selectGroup(): void {
        this.select.select(this.active.groupsSorted, "name", "<?php _('Select Group') ?>").then((grp: GroupState)=> {
            this.printerAction.setActiveGroupId(this.active.slug, grp.id);
        }, ()=> {
        });
    }

    private selected: ServerFolderState;

    transImportTo(g: string): string {
        return "<?php _('Import to $') ?>".replace("$", g);
    }

    transImport(): string {
        return "<?php _('Where to import $?') ?>".replace("$", this.selected.name);
    }

    importModel(): void {
        this.printerAction.importFiles(this.active.slug, this.bFolder, [this.selected], false);
        this.page = 1;
    }

    importJob() {
        this.printerAction.importFiles(this.active.slug, this.bFolder, [this.selected], true);
        this.page = 1;
    }

    refresh() {
        if (this.bFolder) {
            this.bFolder.updateFiles();
        }
    }

    selectFolder(f: ServerFolderState) {
        this.bFolder = new RSBrowseFolder(this.connectionHandler, f);
        this.page = 1;
        this.bFolder.importFileCallback = (imp: ServerFolderState) => {
            this.selected = imp;
            this.page = 2;
        };
    }
}

==> Repetier-Server-Frontend-0.90.1.zip: Repetier-Server-Frontend/wwwsrc/modules/front2/app/import.component.ts <==
/* (C) 2016-2018 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */


import {Component} from '@angular/core';
import {
    ServerFolderState, RSBrowseFolder, GroupState, PrintersState,
    ServerState, PrinterState, PrinterAction, INITIAL_SERVER_FOLDER_STATE,
    ConnectionHandler
} from "@repetier/binding";
import {RSSelect} from "@repetier/front-ui";
import {select} from 'ng2-redux';
import {Observable} from 'rxjs/Observable';
import {ISubscription} from "rxjs/Subscription";

@Component({
    selector: 'rs-import-component',
    template: `
<rs-page>
<side>
    <rs-sideicon title="<?php _('Home') ?>" icon="fa fa-home" link="/"></rs-sideicon>
</side>
<side>
    <rs-sideicon *ngIf="page==1" title="<?php _('Refresh') ?>" icon="fa fa-refresh" (rsclick)="refresh()"></rs-sideicon>
</side>
<side>
    <rs-sideicon *ngIf="server.serverFolders.length > 1 && page==1" title="<?php _('Back') ?>" icon="fa fa-reply" (rsclick)="page=0"></rs-sideicon>
</side>
<main>
<div *ngIf="page==0 && active">
    <h1><?php _('Import') ?></h1>
    <div class="content-h1 margin-leftright" rs-drag>
        <div *ngFor="let f of server.serverFolders" class="margin-bottom">
            <rs-button (hit)="selectFolder(f)" class="secondary full">{{f.name}}</rs-button>
        </div>
    </div>
</div>
<div  *ngIf="page==1">
    <h1><?php _('Import')?>: {{bFolder.activeFolderPath}}</h1>
    <div class="content-h1 margin-leftright" rs-drag>
        <div class="entry-list">
            <div class="entry left buttons" [class.single2]="p.isDir" *ngFor="let p of bFolder?.filesInPath">
                <rs-button class="primary left" (hit)="bFolder.toggleSelectFile(p)"><i class="fa" [class.fa-download]="!p.isDir" [class.fa-arrow-circle-right]="p.isDir"></i></rs-button>
                <h3><i [class]="p.icon"></i> {{p.name}}</h3>
                <p *ngIf="!p.isDir">{{p.size | byte}}</p>
            </div>
        </div>
    </div>
</div>
<div *ngIf="page==2">
    <h1><?php _('Importing ...')?></h1>
    <div class="content-h1 margin-leftright" rs-drag>
    <p>{{transImport()}}</p>
        <rs-button class="secondary margin-leftright margin-bottom" style="display:block" (hit)="selectGroup()">{{group?.name}}</rs-button>
        <rs-button class="secondary margin-leftright margin-bottom" style="display:block" (hit)="importModel()">{{transImportTo(group?.name)}}</rs-button><br>
        <rs-button *ngIf="active.queue.length==0" class="secondary margin-leftright margin-bottom" style="display:block" (hit)="importJob()"><?php _('Print File') ?></rs-button>
        <rs-button *ngIf="active.queue.length!=0" class="secondary margin-leftright margin-bottom" style="display:block" (hit)="importJob()"><?php _('Add to Print Queue') ?></rs-button>
    </div>
</div>
</main>
</rs-page>
    `
})
export class ImportComponent {
    page: number = 0; // 0 = folder select, 1 = file select
    group: GroupState;
    folder: ServerFolderState = Object.assign({}, INITIAL_SERVER_FOLDER_STATE);
    bFolder: RSBrowseFolder;
    importMsg: string;
    printers: PrintersState;
    active: PrinterState;
    server: ServerState;

    @select('printers') printers$: Observable<PrintersState>;
    @select('server') server$: Observable<ServerState>;

    private printersSubscription: ISubscription;
    private serverSubscription: ISubscription;

    constructor(private connectionHandler: ConnectionHandler,
                public select: RSSelect, private printerAction: PrinterAction) {
        this.printersSubscription = this.printers$.subscribe(p => {
            this.printers = p;
            if (p.active) {
                this.active = this.printers.printers[p.active];
                this.group = this.active.groups[this.active.activeGroupId];
            }
        });
        this.serverSubscription = this.server$.subscribe((s: ServerState) => {
            this.server = s;
            if (this.server.serverFolders.length == 1 && this.page == 0) {
                this.selectFolder(this.server.serverFolders[0]);
            }
        });
    }

    ngOnDestroy(): void {
        this.printersSubscription.unsubscribe();
        this.serverSubscription.unsubscribe();
    }

    selectGroup(): void {
        this.select.select(this.active.groupsSortedNoAll, "name", "<?php _('Select Group') ?>").then((grp: GroupState)=> {
            this.printerAction.setActiveGroupId(this.active.slug, grp.id);
        }, ()=> {
        });
    }

    private selected: ServerFolderState;

    transImportTo(g: string): string {
        return "<?php _('Import to $') ?>".replace("$", g);
    }

    transImport(): string {
        return "<?php _('Where to import $?') ?>".replace("$", this.selected.name);
    }

    importModel(): void {
        this.printerAction.importFiles(this.active.slug, this.bFolder, [this.selected], false);
        this.page = 1;
    }

    importJob() {
        this.printerAction.importFiles(this.active.slug, this.bFolder, [this.selected], true);
        this.page = 1;
    }

    refresh() {
        if (this.bFolder) {
            this.bFolder.updateFiles();
        }
    }

    selectFolder(f: ServerFolderState) {
        this.bFolder = new RSBrowseFolder(this.connectionHandler, f);
        this.page = 1;
        this.bFolder.importFileCallback = (imp: ServerFolderState) => {
            this.selected = imp;
            this.page = 2;
        };
    }
}
